@@ -16,19 +16,17 @@ class PDE(Data):
 
     def __init__(
         self,
-        geom,
-        num_outputs,
+        geometry,
         pde,
         bcs,
         num_domain=0,
         num_boundary=0,
         train_distribution="random",
         anchors=None,
-        func=None,
+        solution=None,
         num_test=None,
     ):
-        self.geom = geom
-        self.num_outputs = num_outputs
+        self.geom = geometry
         self.pde = pde
         self.bcs = bcs if isinstance(bcs, (list, tuple)) else [bcs]
 
@@ -37,7 +35,7 @@ class PDE(Data):
         self.train_distribution = train_distribution
         self.anchors = anchors
 
-        self.func = func
+        self.soln = solution
         self.num_test = num_test
 
         self.num_bcs = None
@@ -54,17 +52,22 @@ class PDE(Data):
         def losses_train():
             bcs_start = np.cumsum([0] + self.num_bcs)
             error_f = [fi[bcs_start[-1] :] for fi in f]
-            losses = [loss(tf.zeros(tf.shape(error)), error) for error in error_f]
+            losses = [
+                loss(tf.zeros(tf.shape(error), dtype=config.real(tf)), error)
+                for error in error_f
+            ]
             for i, bc in enumerate(self.bcs):
                 beg, end = bcs_start[i], bcs_start[i + 1]
                 error = bc.error(self.train_x, model.net.inputs, outputs, beg, end)
-                losses.append(loss(tf.zeros(tf.shape(error)), error))
+                losses.append(
+                    loss(tf.zeros(tf.shape(error), dtype=config.real(tf)), error)
+                )
             return losses
 
         def losses_test():
-            return [loss(tf.zeros(tf.shape(fi)), fi) for fi in f] + [
-                tf.constant(0, dtype=config.real(tf)) for _ in self.bcs
-            ]
+            return [
+                loss(tf.zeros(tf.shape(fi), dtype=config.real(tf)), fi) for fi in f
+            ] + [tf.constant(0, dtype=config.real(tf)) for _ in self.bcs]
 
         return tf.cond(tf.equal(model.net.data_id, 0), losses_train, losses_test)
 
@@ -72,7 +75,7 @@ class PDE(Data):
     def train_next_batch(self, batch_size=None):
         self.train_x = self.train_points()
         self.train_x = np.vstack((self.bc_points(), self.train_x))
-        self.train_y = self.func(self.train_x) if self.func else None
+        self.train_y = self.soln(self.train_x) if self.soln else None
         return self.train_x, self.train_y
 
     @run_if_all_none("test_x", "test_y")
@@ -82,7 +85,7 @@ class PDE(Data):
             self.test_y = self.train_y[sum(self.num_bcs) :] if self.train_y else None
         else:
             self.test_x = self.test_points()
-            self.test_y = self.func(self.test_x) if self.func else None
+            self.test_y = self.soln(self.test_x) if self.soln else None
         return self.test_x, self.test_y
 
     def add_anchors(self, anchors):
@@ -92,7 +95,7 @@ class PDE(Data):
             self.anchors = np.vstack((anchors, self.anchors))
         self.train_x = np.vstack((anchors, self.train_x[sum(self.num_bcs) :]))
         self.train_x = np.vstack((self.bc_points(), self.train_x))
-        self.train_y = self.func(self.train_x) if self.func else None
+        self.train_y = self.soln(self.train_x) if self.soln else None
 
     def train_points(self):
         X = np.empty((0, self.geom.dim))
@@ -133,8 +136,7 @@ class TimePDE(PDE):
 
     def __init__(
         self,
-        geomtime,
-        num_outputs,
+        geometryxtime,
         pde,
         ic_bcs,
         num_domain=0,
@@ -142,20 +144,19 @@ class TimePDE(PDE):
         num_initial=0,
         train_distribution="random",
         anchors=None,
-        func=None,
+        solution=None,
         num_test=None,
     ):
         self.num_initial = num_initial
         super(TimePDE, self).__init__(
-            geomtime,
-            num_outputs,
+            geometryxtime,
             pde,
             ic_bcs,
             num_domain,
             num_boundary,
             train_distribution=train_distribution,
             anchors=anchors,
-            func=func,
+            solution=solution,
             num_test=num_test,
         )
 
