@@ -6,7 +6,13 @@ import tensorflow as tf
 
 
 def mean_squared_error(y_true, y_pred):
-    return tf.losses.mean_squared_error(y_true, y_pred)
+    # Warning:
+    # - Do not use ``tf.losses.mean_squared_error``, which casts `y_true` and `y_pred` to ``float32``.
+    # - Do not use ``tf.keras.losses.MSE``, which computes the mean value over the last dimension.
+    # - Do not use ``tf.keras.losses.MeanSquaredError()``, which casts loss to ``float32``
+    #     when calling ``compute_weighted_loss()`` calling ``scale_losses_by_sample_weight()``,
+    #     although it finally casts loss back to the original type.
+    return tf.reduce_mean(tf.math.square(y_true - y_pred))
 
 
 def mean_absolute_percentage_error(y_true, y_pred):
